@@ -171,6 +171,9 @@ class StreamChatAsync(StreamChatInterface, AsyncContextManager):
             "users/delete", data=dict(options, user=delete_type, user_ids=user_ids)
         )
 
+    async def restore_users(self, user_ids: Iterable[str]) -> StreamResponse:
+        return await self.post("users/restore", data={"user_ids": user_ids})
+
     async def deactivate_user(self, user_id: str, **options: Any) -> StreamResponse:
         return await self.post(f"users/{user_id}/deactivate", data=options)
 
@@ -514,7 +517,7 @@ class StreamChatAsync(StreamChatInterface, AsyncContextManager):
         return await self.post("segments", data={"segment": segment})
 
     async def query_segments(self, **params: Any) -> StreamResponse:
-        return await self.post("segments", data=params)
+        return await self.get("segments", params={"payload": json.dumps(params)})
 
     async def update_segment(self, segment_id: str, data: Dict) -> StreamResponse:
         return await self.put(f"segments/{segment_id}", data={"segment": data})
@@ -526,24 +529,23 @@ class StreamChatAsync(StreamChatInterface, AsyncContextManager):
         return await self.post("campaigns", data={"campaign": campaign})
 
     async def query_campaigns(self, **params: Any) -> StreamResponse:
-        return await self.post("campaigns", params)
+        return await self.get("campaigns", params={"payload": json.dumps(params)})
 
     async def update_campaign(self, campaign_id: str, data: Dict) -> StreamResponse:
         return await self.put(f"campaigns/{campaign_id}", data={"campaign": data})
 
-    async def delete_campaign(self, campaign_id: str) -> StreamResponse:
-
-        return await self.delete(f"campaigns/{campaign_id}")
+    async def delete_campaign(self, campaign_id: str, **options: Any) -> StreamResponse:
+        return await self.delete(f"campaigns/{campaign_id}", params=options)
 
     async def schedule_campaign(
-        self, campaign_id: str, send_at: int = None
+        self, campaign_id: str, scheduled_for: int = None
     ) -> StreamResponse:
         return await self.patch(
-            f"campaigns/{campaign_id}/schedule", data={"send_at": send_at}
+            f"campaigns/{campaign_id}/schedule", data={"scheduled_for": scheduled_for}
         )
 
     async def query_recipients(self, **params: Any) -> StreamResponse:
-        return await self.post("recipients", data=params)
+        return await self.get("recipients", params={"payload": json.dumps(params)})
 
     async def stop_campaign(self, campaign_id: str) -> StreamResponse:
         return await self.patch(f"campaigns/{campaign_id}/stop")
