@@ -161,6 +161,9 @@ class StreamChat(StreamChatInterface):
             "users/delete", data=dict(options, user=delete_type, user_ids=user_ids)
         )
 
+    def restore_users(self, user_ids: Iterable[str]) -> StreamResponse:
+        return self.post("users/restore", data={"user_ids": user_ids})
+
     def deactivate_user(self, user_id: str, **options: Any) -> StreamResponse:
         return self.post(f"users/{user_id}/deactivate", data=options)
 
@@ -492,7 +495,7 @@ class StreamChat(StreamChatInterface):
         return self.post("segments", data={"segment": segment})
 
     def query_segments(self, **params: Any) -> StreamResponse:
-        return self.post("segments", data=params)
+        return self.get("segments", params={"payload": json.dumps(params)})
 
     def update_segment(self, segment_id: str, data: Dict) -> StreamResponse:
         return self.put(f"segments/{segment_id}", data={"segment": data})
@@ -504,19 +507,19 @@ class StreamChat(StreamChatInterface):
         return self.post("campaigns", data={"campaign": campaign})
 
     def query_campaigns(self, **params: Any) -> StreamResponse:
-        return self.post("campaigns", data=params)
+        return self.get("campaigns", params={"payload": json.dumps(params)})
 
     def update_campaign(self, campaign_id: str, data: Dict) -> StreamResponse:
         return self.put(f"campaigns/{campaign_id}", data={"campaign": data})
 
-    def delete_campaign(self, campaign_id: str) -> StreamResponse:
-        return self.delete(f"campaigns/{campaign_id}")
+    def delete_campaign(self, campaign_id: str, **options: Any) -> StreamResponse:
+        return self.delete(f"campaigns/{campaign_id}", params=options)
 
     def schedule_campaign(
-        self, campaign_id: str, send_at: int = None
+        self, campaign_id: str, scheduled_for: int = None
     ) -> StreamResponse:
         return self.patch(
-            f"campaigns/{campaign_id}/schedule", data={"send_at": send_at}
+            f"campaigns/{campaign_id}/schedule", data={"scheduled_for": scheduled_for}
         )
 
     def stop_campaign(self, campaign_id: str) -> StreamResponse:
@@ -529,7 +532,7 @@ class StreamChat(StreamChatInterface):
         return self.post(f"campaigns/{campaign_id}/test", data={"users": users})
 
     def query_recipients(self, **params: Any) -> StreamResponse:
-        return self.post("recipients", data=params)
+        return self.get("recipients", params={"payload": json.dumps(params)})
 
     def revoke_tokens(self, since: Union[str, datetime.datetime]) -> StreamResponse:
         if isinstance(since, datetime.datetime):
